@@ -214,10 +214,12 @@ class Monitor:
         scheduler.start()
 
     def scheduler_init(self):
-        if not self.scheduler_list:
+        if self.scheduler_list:
             return [Service(_) for _ in self.scheduler_list]
         else:
             config_scheduler_list = settings.get('MONITOR_SCHEDULERS')
+            if isinstance(config_scheduler_list, str):
+                config_scheduler_list = eval(config_scheduler_list)
             res = []
             for _ in config_scheduler_list:
                 if isinstance(_, list) or isinstance(_, dict):
